package com.ruoyi.project.sems.his.service;

import java.util.List;

import com.ruoyi.project.sems.domain.TSpecdevYlgd;
import com.ruoyi.project.sems.his.domain.TSpechiYlgd;

/**
 * 特种设备压力管道台账历史Service接口
 * 
 * @author ruoyi
 * @date 2021-09-02
 */
public interface ITSpechiYlgdService 
{
    /**
     * 查询特种设备压力管道台账历史
     * 
     * @param id 特种设备压力管道台账历史ID
     * @return 特种设备压力管道台账历史
     */
    public TSpechiYlgd selectTSpechiYlgdById(Long id);

    /**
     * 查询特种设备压力管道台账历史列表
     * 
     * @param tSpechiYlgd 特种设备压力管道台账历史
     * @return 特种设备压力管道台账历史集合
     */
    public List<TSpechiYlgd> selectTSpechiYlgdList(TSpechiYlgd tSpechiYlgd);

    /**
     * 新增特种设备压力管道台账历史
     * 
     * @param tSpechiYlgd 特种设备压力管道台账历史
     * @return 结果
     */
    public int insertTSpechiYlgd(TSpechiYlgd tSpechiYlgd);

    /**
     * 使用台账新增特种设备压力管道台账历史
     * @param tSpecdevYlgd 特种设备压力管道台账
     * @return
     */
    public int insertTSpechiYlgdWithDev(TSpecdevYlgd tSpecdevYlgd);

    /**
     * 修改特种设备压力管道台账历史
     * 
     * @param tSpechiYlgd 特种设备压力管道台账历史
     * @return 结果
     */
    public int updateTSpechiYlgd(TSpechiYlgd tSpechiYlgd);

    /**
     * 批量删除特种设备压力管道台账历史
     * 
     * @param ids 需要删除的特种设备压力管道台账历史ID
     * @return 结果
     */
    public int deleteTSpechiYlgdByIds(Long[] ids);

    /**
     * 删除特种设备压力管道台账历史信息
     * 
     * @param id 特种设备压力管道台账历史ID
     * @return 结果
     */
    public int deleteTSpechiYlgdById(Long id);

    public List<TSpechiYlgd> selectTSpechiYlgdByReform(Long devId);

    /**
     * 根据devid删除特种设备压力管道的台账历史信息
     * @param devId
     * @return
     */
    public int deleteTSpechiYlgdByDevId(Long devId);
}
